@@ -1,6 +1,6 @@
 /*
  *  Off-the-Record Messaging library
- *  Copyright (C) 2004-2005  Nikita Borisov and Ian Goldberg
+ *  Copyright (C) 2004-2007  Ian Goldberg, Chris Alexander, Nikita Borisov
  *                           <otr@cypherpunks.ca>
  *
  *  This library is free software; you can redistribute it and/or
@@ -36,7 +36,7 @@ size_t otrl_base64_encode(char *base64data, const unsigned char *data,
  * The buffer data must contain at least (base64len / 4) * 3 bytes of
  * space.  This function will return the number of bytes actually used.
  */
-size_t otrl_base64_decode(char *data, const unsigned char *base64data,
+size_t otrl_base64_decode(unsigned char *data, const char *base64data,
 	size_t base64len);
 
 /*
